@@ -72,7 +72,7 @@ create_main (void)
     gtk_window_set_title (GTK_WINDOW (main_win), "Asunder");
     
     gtk_window_set_default_size (GTK_WINDOW (main_win), global_prefs->main_window_width, global_prefs->main_window_height);
-    main_icon_pixbuf = create_pixbuf ("asunder.png");
+    main_icon_pixbuf = create_pixbuf ("asunder.svg");
     if (main_icon_pixbuf)
     {
         gtk_window_set_icon (GTK_WINDOW (main_win), main_icon_pixbuf);
@@ -1549,7 +1549,7 @@ toggle_allow_tracknum(void)
 }
 
 const char* 
-GBLprogramName = "Asunder 2.9.5";
+GBLprogramName = "Asunder 2.9.6";
 
 static const char* 
 GBLauthors[2] = {
@@ -1649,6 +1649,9 @@ GBLauthors[2] = {
 "\n"
 "Packages:\n"
 "\n"
+"Kevin \"Eonfge\" Degeling\n"
+"- Flatpak/Flathub setup for Asunder, version 2.9.6\n"
+"\n"
 "Toni Graffy\n"
 "Maintainer of many SuSE packages at PackMan\n"
 "- SuSE packages of Asunder, versions 0.1 - 1.6\n"
@@ -1808,6 +1811,9 @@ GBLtranslators =
 "Fabio Boccaletti\n"
 "- it (Italian) translation of Asunder version 2.3\n"
 "\n"
+"Albano Battistella\n"
+"- it (Italian) translation of Asunder version 2.9.5\n"
+"\n"
 "UTUMI Hirosi\n"
 "- ja (Japanese) translation of Asunder versions 1.0 - 1.5\n"
 "\n"
@@ -1853,6 +1859,9 @@ GBLtranslators =
 "Sergio Marques\n"
 "- pt (Portuguese) translation of Asunder version 1.9\n"
 "\n"
+"Ricardo Simões\n"
+"- pt (Portuguese) translation of Asunder version 2.9.5\n"
+"\n"
 "Flipe Augusto\n"
 "- pt_BR (Portuguese/Brazil) translation of Asunder versions 0.8.1 - 1.9\n"
 "\n"
@@ -1868,6 +1877,9 @@ GBLtranslators =
 "Paulo Roberto de Oliveira Castro\n"
 "- pt_BR (Portuguese/Brazil) translation of Asunder version 2.2\n"
 "\n"
+"Gilberto F da Silva\n"
+"- pt_BR (Portuguese/Brazil) translation of Asunder version 2.9.5\n"
+"\n"
 "Alexandre Prokoudine\n"
 "- ru (Russian) translation of Asunder version 1.9.2\n"
 "\n"
@@ -1884,7 +1896,7 @@ GBLtranslators =
 "- sl (Slovenian) translation of Asunder versions 1.9 - 2.1\n"
 "\n"
 "Besnik Bleta\n"
-"- sq (Albanian) translation of Asunder versions 0.8 - 1.9\n"
+"- sq (Albanian) translation of Asunder versions 0.8 - 2.9.4\n"
 "\n"
 "Milan Puzic\n"
 "- sr (Serbian) translation of Asunder versions 1.0, 1.9\n"
@@ -1908,8 +1920,8 @@ GBLtranslators =
 "http://makki.urducoder.com/\n"
 "- ur_PK (Urdu/Pakistan) translation of Asunder version 2.0\n"
 "\n"
-"Tiansworld\n"
-"- zh_CN (Simplified Chineese) translation of Asunder version 2.3\n"
+"Shixiong Tian\n"
+"- zh_CN (Simplified Chineese) translation of Asunder versions 2.3, 2.9.5\n"
 "\n"
 "Jeff Bai\n"
 "- zh_CN (Simplified Chineese) translation of Asunder version 2.5\n"
